import requests

class RabbitMQAPI:
    def __init__(self, base_url, username, password):
        self.base_url = base_url
        self.auth = (username, password)

    def get_queues(self):
        url = f"{self.base_url}/queues"
        response = requests.get(url, auth=self.auth)
        if response.status_code == 200:
            return response.json()
        else:
            raise Exception(f"Error accessing RabbitMQ API: {response.text}")



from django.core.management.base import BaseCommand
from .rabbitmq_api import RabbitMQAPI

class Command(BaseCommand):
    help = 'Fetches and displays RabbitMQ queues'

    def handle(self, *args, **options):
        # Initialize RabbitMQAPI with connection details
        rabbitmq_api = RabbitMQAPI("http://localhost:15672/api", "admin", "password")
        
        # Fetch queues using RabbitMQAPI
        queues = rabbitmq_api.get_queues()
        
        # Display queue details
        self.stdout.write("RabbitMQ Queues:")
        for queue in queues:
            self.stdout.write(f"Queue Name: {queue['name']}")
            self.stdout.write(f"Message Count: {queue['messages']}")
            self.stdout.write(f"Consumers: {queue['consumers']}")
            self.stdout.write('\n')



from setuptools import setup, find_packages
import io
import re

with io.open("README.md") as f:
    description = f.read()

with io.open("__init__.py", "rt", encoding="utf8") as f:
    version = re.search(r'__version__ = "(.*?)"', f.read()).group(1)

setup(
    name='django-rabbitmq-utils',
    version='0.0.1',
    packages=find_packages(),
    install_requires=[
        'pika',  # RabbitMQ client library
        'kombu',
        'requests',
        'Django',
    ],
    description='Enhance RabbitMQ services for a Python Django application',
    long_description=description,
    long_description_content_type="text/markdown",
    author='Soniya Sharma',
    author_email='sharmasoniya6868@email.com',
    url='https://github.com/Soniyasharma6868/django_rabbitmq_utils',
    license="MIT",
    project_urls={
        "Source": "https://github.com/Soniyasharma6868/django_rabbitmq_utils",
    },
    classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    zip_safe=False,
    python_requires=">=3",
)



import pika

def get_rabbitmq_connection():
    # Define your RabbitMQ connection parameters
    credentials = pika.PlainCredentials('guest', 'guest')
    parameters = pika.ConnectionParameters('localhost', 5672, '/', credentials)

    # Establish the RabbitMQ connection
    connection = pika.BlockingConnection(parameters)
    return connection

def publish_message(queue_name, message):
    connection = get_rabbitmq_connection()
    channel = connection.channel()

    # Declare the queue
    channel.queue_declare(queue=queue_name)

    # Publish the message to the queue
    channel.basic_publish(exchange='', routing_key=queue_name, body=message)

    # Close the connection
    connection.close()


# seetings.py
# COMMANDS = {
#     **rabbitmq_integration.register_commands()
# }